@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
 from ocp_resources.resource import NamespacedResource
-from ocp_resources.utils import TimeoutSampler
+from ocp_resources.utils import TimeoutSampler, TimeoutWatch
 
 
 class Deployment(NamespacedResource):
@@ -21,11 +21,11 @@ class Deployment(NamespacedResource):
         Returns:
             Deployment is updated successfully
         """
-        body = super().to_dict()
-        body.update({"spec": {"replicas": replica_count}})
+        super().to_dict()
+        self.res.update({"spec": {"replicas": replica_count}})
 
         self.logger.info(f"Set deployment replicas: {replica_count}")
-        return self.update(resource_dict=body)
+        return self.update(resource_dict=self.res)
 
     def wait_for_replicas(self, deployed=True, timeout=TIMEOUT_4MINUTES):
         """
@@ -39,19 +39,27 @@ class Deployment(NamespacedResource):
             TimeoutExpiredError: If not availableReplicas is equal to replicas.
         """
         self.logger.info(f"Wait for {self.kind} {self.name} to be deployed: {deployed}")
-        samples = TimeoutSampler(
+
+        timeout_watcher = TimeoutWatch(timeout=timeout)
+        for sample in TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
+            func=lambda: self.exists,
+        ):
+            if sample:
+                break
+
+        samples = TimeoutSampler(
+            wait_timeout=timeout_watcher.remaining_time(),
+            sleep=1,
             exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=self.api.get,
-            field_selector=f"metadata.name=={self.name}",
+            func=lambda: self.instance,
         )
         for sample in samples:
-            if sample.items:
-                instance = sample.items[0]
-                status = instance.status
+            if sample:
+                status = sample.status
 
-                spec_replicas = instance.spec.replicas
+                spec_replicas = sample.spec.replicas
                 total_replicas = status.replicas or 0
                 updated_replicas = status.updatedReplicas or 0
                 available_replicas = status.availableReplicas or 0
@@ -59,9 +67,6 @@ class Deployment(NamespacedResource):
 
                 if (
                     (deployed and spec_replicas)
-                    and spec_replicas
-                    == updated_replicas
-                    == available_replicas
-                    == ready_replicas
+                    and spec_replicas == updated_replicas == available_replicas == ready_replicas
                 ) or not (deployed or spec_replicas or total_replicas):
                     return
